Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(178)

Unified Diff: remoting/client/ios/app/host_collection_view_cell.h

Issue 2828113002: Provide HostView with data required for creating a new and session, and render for CRD iOS. (Closed)
Patch Set: fixing issue based on feedback. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/client/ios/app/host_collection_view_cell.h
diff --git a/remoting/client/ios/app/host_collection_view_cell.h b/remoting/client/ios/app/host_collection_view_cell.h
index 9a18871b450a0b71696fb0ee237d421e23ffc35c..50f2da2de106331913fcdf7b6a77bd743e1ef666 100644
--- a/remoting/client/ios/app/host_collection_view_cell.h
+++ b/remoting/client/ios/app/host_collection_view_cell.h
@@ -9,10 +9,14 @@
#import "ios/third_party/material_components_ios/src/components/Collections/src/MaterialCollections.h"
+@class HostInfo;
+
@interface HostCollectionViewCell : MDCCollectionViewCell
-// Update a cell with a title and status. Typically called for cell reuse.
-- (void)populateContentWithTitle:(NSString*)title status:(NSString*)status;
+// Update a cell with host info. Typically called for cell reuse.
+- (void)populateContentWithHostInfo:(HostInfo*)hostInfo;
+
+@property(readonly, nonatomic) HostInfo* hostInfo;
@end

Powered by Google App Engine
This is Rietveld 408576698